@@ -1,3 +1,40 @@
+"""
+## Amazon ECR Construct Library
+
+<html></html>---
+
+
+![Stability: Stable](https://img.shields.io/badge/stability-Stable-success.svg?style=for-the-badge)
+
+---
+<html></html>
+
+This package contains constructs for working with Amazon Elastic Container Registry.
+
+### Repositories
+
+Define a repository by creating a new instance of `Repository`. A repository
+holds multiple verions of a single container image.
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+repository = ecr.Repository(self, "Repository")
+```
+
+### Automatically clean up repositories
+
+You can set life cycle rules to automatically clean up old images from your
+repository. The first life cycle rule that matches an image will be applied
+against that image. For example, the following deletes images older than
+30 days, while keeping all images tagged with prod (note that the order
+is important here):
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+repository.add_lifecycle_rule(tag_prefix_list=["prod"], max_image_count=9999)
+repository.add_lifecycle_rule(max_image_age_days=cdk.Duration.days(30))
+```
+"""
 import abc
 import datetime
 import enum
@@ -12,7 +49,8 @@ from jsii.python import classproperty
 import aws_cdk.aws_events
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ecr", "1.12.0", __name__, "aws-ecr@1.12.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ecr", "1.16.1", __name__, "aws-ecr@1.16.1.jsii.tgz")
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnRepository(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ecr.CfnRepository"):
     """A CloudFormation ``AWS::ECR::Repository``.
 
@@ -36,6 +74,17 @@ class CfnRepository(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
         jsii.create(CfnRepository, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -330,6 +379,36 @@ class IRepository(aws_cdk.core.IResource, jsii.compat.Protocol):
         """
         ...
 
+    @jsii.member(jsii_name="onEvent")
+    def on_event(self, id: str, *, description: typing.Optional[str]=None, event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern]=None, rule_name: typing.Optional[str]=None, target: typing.Optional[aws_cdk.aws_events.IRuleTarget]=None) -> aws_cdk.aws_events.Rule:
+        """Defines a CloudWatch event rule which triggers for repository events.
+
+        Use
+        ``rule.addEventPattern(pattern)`` to specify a filter.
+
+        :param id: -
+        :param options: -
+        :param description: A description of the rule's purpose. Default: - No description
+        :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
+        :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        """
+        ...
+
+    @jsii.member(jsii_name="onImageScanCompleted")
+    def on_image_scan_completed(self, id: str, *, image_tags: typing.Optional[typing.List[str]]=None, description: typing.Optional[str]=None, event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern]=None, rule_name: typing.Optional[str]=None, target: typing.Optional[aws_cdk.aws_events.IRuleTarget]=None) -> aws_cdk.aws_events.Rule:
+        """Defines an AWS CloudWatch event rule that can trigger a target when the image scan is completed.
+
+        :param id: The id of the rule.
+        :param options: Options for adding the rule.
+        :param image_tags: Only watch changes to the image tags spedified. Leave it undefined to watch the full repository. Default: - Watch the changes to the repository with all image tags
+        :param description: A description of the rule's purpose. Default: - No description
+        :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
+        :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        """
+        ...
+
     @jsii.member(jsii_name="repositoryUriForTag")
     def repository_uri_for_tag(self, tag: typing.Optional[str]=None) -> str:
         """Returns the URI of the repository for a certain tag. Can be used in ``docker push/pull``.
@@ -446,6 +525,40 @@ class _IRepositoryProxy(jsii.proxy_for(aws_cdk.core.IResource)):
 
         return jsii.invoke(self, "onCloudTrailImagePushed", [id, options])
 
+    @jsii.member(jsii_name="onEvent")
+    def on_event(self, id: str, *, description: typing.Optional[str]=None, event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern]=None, rule_name: typing.Optional[str]=None, target: typing.Optional[aws_cdk.aws_events.IRuleTarget]=None) -> aws_cdk.aws_events.Rule:
+        """Defines a CloudWatch event rule which triggers for repository events.
+
+        Use
+        ``rule.addEventPattern(pattern)`` to specify a filter.
+
+        :param id: -
+        :param options: -
+        :param description: A description of the rule's purpose. Default: - No description
+        :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
+        :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        """
+        options = aws_cdk.aws_events.OnEventOptions(description=description, event_pattern=event_pattern, rule_name=rule_name, target=target)
+
+        return jsii.invoke(self, "onEvent", [id, options])
+
+    @jsii.member(jsii_name="onImageScanCompleted")
+    def on_image_scan_completed(self, id: str, *, image_tags: typing.Optional[typing.List[str]]=None, description: typing.Optional[str]=None, event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern]=None, rule_name: typing.Optional[str]=None, target: typing.Optional[aws_cdk.aws_events.IRuleTarget]=None) -> aws_cdk.aws_events.Rule:
+        """Defines an AWS CloudWatch event rule that can trigger a target when the image scan is completed.
+
+        :param id: The id of the rule.
+        :param options: Options for adding the rule.
+        :param image_tags: Only watch changes to the image tags spedified. Leave it undefined to watch the full repository. Default: - Watch the changes to the repository with all image tags
+        :param description: A description of the rule's purpose. Default: - No description
+        :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
+        :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        """
+        options = OnImageScanCompletedOptions(image_tags=image_tags, description=description, event_pattern=event_pattern, rule_name=rule_name, target=target)
+
+        return jsii.invoke(self, "onImageScanCompleted", [id, options])
+
     @jsii.member(jsii_name="repositoryUriForTag")
     def repository_uri_for_tag(self, tag: typing.Optional[str]=None) -> str:
         """Returns the URI of the repository for a certain tag. Can be used in ``docker push/pull``.
@@ -632,6 +745,87 @@ class OnCloudTrailImagePushedOptions(aws_cdk.aws_events.OnEventOptions):
         return 'OnCloudTrailImagePushedOptions(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.data_type(jsii_type="@aws-cdk/aws-ecr.OnImageScanCompletedOptions", jsii_struct_bases=[aws_cdk.aws_events.OnEventOptions], name_mapping={'description': 'description', 'event_pattern': 'eventPattern', 'rule_name': 'ruleName', 'target': 'target', 'image_tags': 'imageTags'})
+class OnImageScanCompletedOptions(aws_cdk.aws_events.OnEventOptions):
+    def __init__(self, *, description: typing.Optional[str]=None, event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern]=None, rule_name: typing.Optional[str]=None, target: typing.Optional[aws_cdk.aws_events.IRuleTarget]=None, image_tags: typing.Optional[typing.List[str]]=None):
+        """Options for the OnImageScanCompleted method.
+
+        :param description: A description of the rule's purpose. Default: - No description
+        :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
+        :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        :param image_tags: Only watch changes to the image tags spedified. Leave it undefined to watch the full repository. Default: - Watch the changes to the repository with all image tags
+        """
+        self._values = {
+        }
+        if description is not None: self._values["description"] = description
+        if event_pattern is not None: self._values["event_pattern"] = event_pattern
+        if rule_name is not None: self._values["rule_name"] = rule_name
+        if target is not None: self._values["target"] = target
+        if image_tags is not None: self._values["image_tags"] = image_tags
+
+    @property
+    def description(self) -> typing.Optional[str]:
+        """A description of the rule's purpose.
+
+        default
+        :default: - No description
+        """
+        return self._values.get('description')
+
+    @property
+    def event_pattern(self) -> typing.Optional[aws_cdk.aws_events.EventPattern]:
+        """Additional restrictions for the event to route to the specified target.
+
+        The method that generates the rule probably imposes some type of event
+        filtering. The filtering implied by what you pass here is added
+        on top of that filtering.
+
+        default
+        :default: - No additional filtering based on an event pattern.
+
+        see
+        :see: http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/CloudWatchEventsandEventPatterns.html
+        """
+        return self._values.get('event_pattern')
+
+    @property
+    def rule_name(self) -> typing.Optional[str]:
+        """A name for the rule.
+
+        default
+        :default: AWS CloudFormation generates a unique physical ID.
+        """
+        return self._values.get('rule_name')
+
+    @property
+    def target(self) -> typing.Optional[aws_cdk.aws_events.IRuleTarget]:
+        """The target to register for the event.
+
+        default
+        :default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        """
+        return self._values.get('target')
+
+    @property
+    def image_tags(self) -> typing.Optional[typing.List[str]]:
+        """Only watch changes to the image tags spedified. Leave it undefined to watch the full repository.
+
+        default
+        :default: - Watch the changes to the repository with all image tags
+        """
+        return self._values.get('image_tags')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'OnImageScanCompletedOptions(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 @jsii.data_type(jsii_type="@aws-cdk/aws-ecr.RepositoryAttributes", jsii_struct_bases=[], name_mapping={'repository_arn': 'repositoryArn', 'repository_name': 'repositoryName'})
 class RepositoryAttributes():
     def __init__(self, *, repository_arn: str, repository_name: str):
@@ -754,6 +948,40 @@ class RepositoryBase(aws_cdk.core.Resource, metaclass=jsii.JSIIAbstractClass, js
 
         return jsii.invoke(self, "onCloudTrailImagePushed", [id, options])
 
+    @jsii.member(jsii_name="onEvent")
+    def on_event(self, id: str, *, description: typing.Optional[str]=None, event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern]=None, rule_name: typing.Optional[str]=None, target: typing.Optional[aws_cdk.aws_events.IRuleTarget]=None) -> aws_cdk.aws_events.Rule:
+        """Defines a CloudWatch event rule which triggers for repository events.
+
+        Use
+        ``rule.addEventPattern(pattern)`` to specify a filter.
+
+        :param id: -
+        :param options: -
+        :param description: A description of the rule's purpose. Default: - No description
+        :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
+        :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        """
+        options = aws_cdk.aws_events.OnEventOptions(description=description, event_pattern=event_pattern, rule_name=rule_name, target=target)
+
+        return jsii.invoke(self, "onEvent", [id, options])
+
+    @jsii.member(jsii_name="onImageScanCompleted")
+    def on_image_scan_completed(self, id: str, *, image_tags: typing.Optional[typing.List[str]]=None, description: typing.Optional[str]=None, event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern]=None, rule_name: typing.Optional[str]=None, target: typing.Optional[aws_cdk.aws_events.IRuleTarget]=None) -> aws_cdk.aws_events.Rule:
+        """Defines an AWS CloudWatch event rule that can trigger a target when an image scan is completed.
+
+        :param id: The id of the rule.
+        :param options: Options for adding the rule.
+        :param image_tags: Only watch changes to the image tags spedified. Leave it undefined to watch the full repository. Default: - Watch the changes to the repository with all image tags
+        :param description: A description of the rule's purpose. Default: - No description
+        :param event_pattern: Additional restrictions for the event to route to the specified target. The method that generates the rule probably imposes some type of event filtering. The filtering implied by what you pass here is added on top of that filtering. Default: - No additional filtering based on an event pattern.
+        :param rule_name: A name for the rule. Default: AWS CloudFormation generates a unique physical ID.
+        :param target: The target to register for the event. Default: - No target is added to the rule. Use ``addTarget()`` to add a target.
+        """
+        options = OnImageScanCompletedOptions(image_tags=image_tags, description=description, event_pattern=event_pattern, rule_name=rule_name, target=target)
+
+        return jsii.invoke(self, "onImageScanCompleted", [id, options])
+
     @jsii.member(jsii_name="repositoryUriForTag")
     def repository_uri_for_tag(self, tag: typing.Optional[str]=None) -> str:
         """Returns the URL of the repository. Can be used in ``docker push/pull``.
@@ -986,6 +1214,6 @@ class TagStatus(enum.Enum):
     UNTAGGED = "UNTAGGED"
     """Rule applies to untagged images."""
 
-__all__ = ["CfnRepository", "CfnRepositoryProps", "IRepository", "LifecycleRule", "OnCloudTrailImagePushedOptions", "Repository", "RepositoryAttributes", "RepositoryBase", "RepositoryProps", "TagStatus", "__jsii_assembly__"]
+__all__ = ["CfnRepository", "CfnRepositoryProps", "IRepository", "LifecycleRule", "OnCloudTrailImagePushedOptions", "OnImageScanCompletedOptions", "Repository", "RepositoryAttributes", "RepositoryBase", "RepositoryProps", "TagStatus", "__jsii_assembly__"]
 
 publication.publish()
